<?php

namespace App\Livewire\Category;

use Livewire\Component;
use App\Models\categorias;
use Livewire\Attributes\On;
use Livewire\Attributes\Title;
use Livewire\WithPagination;


#[Title('Categorias')]
class CategoryComponent extends Component
{
    use WithPagination;
    // propiedades clase
    public $search='';
    public $totalRegistros=0;
    public $cant=5;
  
    // propiedades modelo
    public $nombre;
    public $Id;
 
    public function render()
    {
        if($this->search!=''){
            $this->resetPage();

        }
        $this->totalRegistros = categorias::count();

        $categories = categorias::where('nombre','like','%'.$this->search.'%')
                            ->orderBy('id','desc')
                            ->paginate($this->cant);
        //$categories = collect();
        return view('livewire.category.category-component',['categories' => $categories]);
    }
    public function mount(){
        
    }

    public function create(){
        $this->Id=0;
        $this->reset(['nombre']);
        $this->resetErrorBag();
        $this->dispatch('open-modal','modalCategory');   
    }
    //crear la categoria
    public function store(){
        // dump('Crear category');
        $rules = [
            'nombre' => 'required|min:5|max:255|unique:categorias'  
  
          ];
          $messages = [
                  'nombre.required' => 'El nombre es requerido',
                  'nombre.min' => 'El nombre debe tener minimo 5 caracteres',
                  'nombre.max' => 'El nombre no debe superar los 255 caracteres',
                  'nombre.unique' => 'El nombre de la categoria ya esta en uso'
          ];
          $this->validate($rules,$messages);
  
          $category = new categorias();
          $category->nombre = $this->nombre;
          $category->save();
  
        $this->dispatch('close-modal','modalCategory');
        $this->dispatch('msg','Categoria creada correctamente');

        $this->reset(['nombre']);
    }
    public function edit(categorias $category){
        $this->Id = $category->id;
        $this->nombre = $category->nombre;
        $this->dispatch('open-modal','modalCategory');

        //dump($category);

    }

    public function update(categorias $category){
        //dump($category);
        $rules = [
            'nombre' => 'required|min:5|max:255|unique:categorias,id,'.$this->Id  
  
          ];
          $messages = [
                  'nombre.required' => 'El nombre es requerido',
                  'nombre.min' => 'El nombre debe tener minimo 5 caracteres',
                  'nombre.max' => 'El nombre no debe superar los 255 caracteres',
                  'nombre.unique' => 'El nombre de la categoria ya esta en uso'
          ];
          $this->validate($rules,$messages);

          $category->nombre = $this->nombre;
          $category->update();

          $this->dispatch('close-modal','modalCategory');
          $this->dispatch('msg','Categoria editada correctamente');
  
          $this->reset(['nombre']);
    }

    #[On('destroyCategory')]
    public function destroy($id){
        //dump($id);
        $category = categorias::findOrfail($id);
        $category->delete();
        $this->dispatch('msg','Categoria ha sido eliminada correctamente');
    }

}
