<?php

namespace App\Livewire\Client;

use Livewire\Component;
use Livewire\Attributes\On;
use Livewire\Attributes\Title;
use App\Models\clientes;
use Livewire\WithPagination;

#[Title('Clientes')]
class ClientComponent extends Component
{
    use WithPagination;
    // propiedades clase
    public $search='';
    public $totalRegistros=0;
    public $cant=5;
  
    // propiedades modelo
    public $Id;
    public $nombre;
    public $clave;
    public $telefono;
    public $mail;
    public $empresa;
    public $contacto;
    
    public function render()
    {
        if($this->search!='') {
        $this->resetPage();

        }
    $this->totalRegistros = clientes::count();

    $clientes = clientes::where('nombre','like','%'.$this->search.'%')
                        ->orderBy('id','desc')
                        ->paginate($this->cant);
    
        return view('livewire.client.client-component',[
            'clientes'=> $clientes
        ]);
    }
    public function create(){
        $this->Id=0;
        $this->clean();
        $this->dispatch('open-modal','modalClient');   
    }
    public function store(){
        // dump('Crear cliente');
        $rules = [
            'nombre' => 'required|min:5|max:255',  
            'clave' => 'required|min:5|max:255|unique:clientes',
            'mail' => 'max:255|email|nullable'  
          ];
          
          $this->validate($rules);
  
          $client = new clientes();
          $client->nombre = $this->nombre;
          $client->clave = $this->clave;
          $client->telefono = $this->telefono;
          $client->mail = $this->mail;
          $client->empresa = $this->empresa;
          $client->contacto = $this->contacto;
          $client->save();
  
        $this->dispatch('close-modal','modalClient');
        $this->dispatch('msg','Cliente creado correctamente');

        $this->clean();
    }

    public function edit(clientes $client){
            $this->clean();

            $this->Id = $client->id;
            $this->nombre = $client->nombre;
            $this->clave = $client->clave;
            $this->telefono = $client->telefono;
            $this->mail = $client->mail;
            $this->empresa = $client->empresa;
            $this->contacto = $client->contacto;

            $this->dispatch('open-modal','modalClient');
       
    }
    
    public function update(clientes $client){
  
        $rules = [
            'nombre' => 'required|min:5|max:255',
            'clave' => 'required|min:5|max:50|unique:clientes,id,'.$this->Id,  
            'mail' => 'max:255|email|nullable'
          ];
          
          $this->validate($rules);

          $client->nombre = $this->nombre;
          $client->clave = $this->clave;
          $client->telefono = $this->telefono;
          $client->mail = $this->mail;
          $client->empresa = $this->empresa;
          $client->contacto = $this->contacto;
          $client->update();

          $this->dispatch('close-modal','modalClient');
          $this->dispatch('msg','Cliente editado correctamente');
  
          $this->clean();
    }

    #[On('destroyClient')]
    public function destroy($id){
        
        $client = clientes::findOrfail($id);
        $client->delete();
        $this->dispatch('msg','Cliente eliminado correctamente');
    }

        public function clean(){
        $this->reset(['nombre','clave','telefono','mail','empresa','contacto']);
        $this->resetErrorBag();
    }
}
