<?php

namespace App\Livewire\Product;

use App\Models\productos;
use App\Models\categorias;
use App\Models\materiales;
use App\Models\images;
use Livewire\Component;
use Livewire\Attributes\Computed;
use Livewire\Attributes\Title;
use Illuminate\Support\Facades\Storage;
use Livewire\WithFileUploads;
use Livewire\WithPagination;
use Livewire\Attributes\On;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use Iluminate\Suport\Facades\App;

#[Title('Productos')]
class ProductComponent extends Component
{
    use WithFileUploads;
    use WithPagination;

     // propiedades clase
    public $search='';
    public $totalRegistros=0;
    public $cant=5;
  
      // propiedades modelo
      public $Id=0;
      public $nombre;
      public $descripcion;
      public $cantidad=1;
      public $costo=10;
      public $precio=10;
      public $fecha_vencimiento;
      public $materiales_id;
      public $clave;
      public $color;
      public $resistencia;
      public $flauta;
      public $ancho=50;
      public $largo=50;
      public $activo=1;
      public $image;  
      public $categorias_id;
      public $imageModel; 
      
    public function render()
    {
   
        $this->totalRegistros = productos::count();

        $products = productos::where('nombre','like','%'.$this->search.'%')
                            ->orderBy('id','desc')
                            ->paginate($this->cant);    
    
        return view('livewire.product.product-component',['products' => $products]);
    }

    #[Computed()]    
    public function categories(){
        return categorias::all();
    }

    #[Computed()]    
    public function materiales(){
        return materiales::all();
    }

    public function calcula(productos $product){
        //dump($product);
        
        $this->cantidad = $product->cantidad;
        $this->costo = $product->costo;
        $this->ancho = $product->ancho;
        $this->largo = $product->largo;
        $calcula= $product->ancho/100 * $product->largo/100;

        $this->precio = $product->costo*$product->cantidad*$calcula;
        
        $this->dispatch('open-modal','modalProduct');
    }

    public function create(){
        $this->Id=0;
        $this->clean();
        
        $this->dispatch('open-modal','modalProduct');   
    }

    //crear producto
    public function store(){
         //dump('crear cateoria');
        $rules = [
            'nombre' => 'required|min:5|max:255|unique:categorias', 
            'descripcion' => 'max:255',
            'cantidad' => 'required|numeric',
            'costo' => 'required|numeric',
            'categorias_id' => 'required|numeric',
            'ancho' => 'required|numeric|min:30|max:2170', 
            'largo' => 'required|numeric|min:50|max:3000',      
          ];
          
          $this->validate($rules);
          $product =new productos();

            $product->nombre = $this->nombre;
            $product->descripcion = $this->descripcion;
            $product->cantidad = $this->cantidad;
            $product->costo = $this->costo;
            $product->precio = $this->precio;
            $product->fecha_vencimiento = $this->fecha_vencimiento;
            
            $product->clave = $this->clave;
            $product->color = $this->color;
            $product->resistencia = $this->resistencia;
            $product->flauta = $this->flauta;
            $product->ancho = $this->ancho;
            $product->largo = $this->largo;
            $product->categorias_id = $this->categorias_id;
            $product->activo = $this->activo;
            $product->save();

            if($this->image){
                $customName = 'products/'.uniqid().'.'.$this->image->extension();
                $this->image->storeAs('public',$customName);
                $product->image()->create(['url'=>$customName]);

              }
    
            
        $this->dispatch('close-modal','modalProduct');
        $this->dispatch('msg','Producto creada correctamente');
        $this->clean();
    }

    public function edit(productos $product){
        $this->clean();

        $this->Id = $product->id;
        $this->nombre = $product->nombre;
        $this->descripcion = $product->descripcion;
        $this->cantidad = $product->cantidad;
        $this->costo = $product->costo;
        $this->precio = $product->precio;
        $this->fecha_vencimiento = $product->fecha_vencimiento;

        $this->clave = $product->clave;
        $this->color = $product->color;
        $this->resistencia = $product->resistencia;
        $this->flauta = $product->flauta;
        $this->ancho = $product->ancho;
        $this->largo = $product->largo;
        $this->categorias_id = $product->categorias_id;
        $this->activo = $product->activo;
        $this->imageModel = $product->image;


        $this->dispatch('open-modal','modalProduct');

        //dump($category);

    }

    public function update(productos $product){
        
        $rules = [
            'nombre' => 'required|min:5|max:255|unique:productos,id,'.$this->Id,
            'descripcion' => 'max:255',
            'cantidad' => 'required|numeric',
            'costo' => 'required|numeric',
            'categorias_id' => 'required|numeric',
            'ancho' => 'required|numeric|min:30|max:2170', 
            'largo' => 'required|numeric|min:50|max:3000',
    
  
          ];
          
          $this->validate($rules);

          $product->nombre = $this->nombre;
          $product->descripcion = $this->descripcion;
          $product->costo = $this->costo;
          $product->precio = $this->precio;
          $product->cantidad = $this->cantidad;
          $product->fecha_vencimiento = $this->fecha_vencimiento;
          $product->clave = $this->clave;
          $product->color = $this->color;
          $product->resistencia = $this->resistencia;
          $product->ancho = $this->ancho;
          $product->largo = $this->largo;
          $product->flauta = $this->flauta;
          $product->categorias_id = $this->categorias_id;
          $product->activo = $this->activo;

          $product->update();

          if($this->image){
            if($product->image!=null){
                Storage::delete('public/'.$product->image->url);
                $product->image()->delete();
            }
            $customName = 'products/'.uniqid().'.'.$this->image->extension();
            $this->image->storeAs('public',$customName);
            $product->image()->create(['url'=>$customName]);
        
          }

          $this->dispatch('close-modal','modalProduct');
          $this->dispatch('msg','Producto editado correctamente');
  
          $this->reset(['nombre']);
    }

        //metodo encargado de limpiar el form
    public function clean(){
        $this->reset(['Id','nombre','image','descripcion','fecha_vencimiento','categorias_id','clave','color','flauta','resistencia']);
        $this->resetErrorBag();
    }

    #[On('destroyProduct')]
    public function destroy($id){
        
        $product = productos::findOrfail($id);
        //@dump($product);
       
            if($product->image!=null){
                Storage::delete('public/'.$product->image->url);
                $product->image()->delete();
            }
                  

        $product->delete();
        
        $this->dispatch('msg','Producto eliminado correctamente');


    }

    public function report()
    {
        
        $products = productos::all();
        //$products = productos::where('nombre','like','%'.$this->search.'%')
        //->orderBy('id','desc');
           
       
       // @dump($products);
        $pdf = Pdf::loadView('products.report',['products' => $products]);
        //return $pdf->stream('products_report.pdf');
        return response()->streamDownload(function () use ($pdf) {
            echo $pdf->stream();
            }, 'products_report.pdf');
    }
}

